%define anolis_release 1
%bcond_without mingw

Name:		    fltk
Version:	    1.3.8
Release:	    %{anolis_release}%{?dist}
Summary:	    C++ user interface toolkit
License:	    LGPL-2.0-or-later with exceptions	
URL:                http://www.fltk.org/
Source0:            http://fltk.org/pub/%{name}/%{version}/%{name}-%{version}-source.tar.gz
Source1:     	    fltk-config.sh

Patch0:             fltk-cmake.patch
# add lib64 support, drop extraneous libs (bug #708185) and ldflags (#1112930)
Patch1:             fltk-1.3.4-fltk_config.patch
# Fix cmake install location for MinGW build
Patch2:             mingw-fltk-cmake.patch

BuildRequires:      cmake
BuildRequires:      desktop-file-utils
BuildRequires:      doxygen
BuildRequires:      fltk-fluid
BuildRequires:      gcc-c++
BuildRequires:      make
BuildRequires:      texlive-latex
BuildRequires:      pkgconfig(libjpeg)
BuildRequires:      pkgconfig(libpng)
BuildRequires:      pkgconfig(gl) pkgconfig(glu) 
BuildRequires:      pkgconfig(ice)
BuildRequires:      pkgconfig(sm) 
BuildRequires:      pkgconfig(xext) pkgconfig(xinerama) pkgconfig(xft) pkgconfig(xt) pkgconfig(x11) 
BuildRequires:      pkgconfig(xcursor)
BuildRequires:      pkgconfig(xproto)
BuildRequires:      pkgconfig(zlib)

%if %{with mingw}
# MinGW
BuildRequires:      mingw32-filesystem >= 95
BuildRequires:      mingw32-gcc
BuildRequires:      mingw32-binutils
BuildRequires:      mingw32-gettext
BuildRequires:      mingw32-win-iconv
BuildRequires:      mingw32-zlib
# Libraries
BuildRequires:      mingw32-libpng
BuildRequires:      mingw32-libjpeg

BuildRequires:      mingw64-filesystem >= 95
BuildRequires:      mingw64-gcc
BuildRequires:      mingw64-binutils
BuildRequires:      mingw64-gettext
BuildRequires:      mingw64-win-iconv
BuildRequires:      mingw64-zlib
# Libraries
BuildRequires:      mingw64-libpng
BuildRequires:      mingw64-libjpeg
%endif


%description
FLTK (pronounced "fulltick") is a cross-platform C++ GUI toolkit. \
It provides modern GUI functionality without the bloat, and supports \
3D graphics via OpenGL and its built-in GLUT emulation.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       libstdc++-devel
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(gl) pkgconfig(glu)
Requires:       pkgconfig(ice) pkgconfig(sm)
Requires:       pkgconfig(xft) pkgconfig(xt) pkgconfig(x11)
Requires:       pkgconfig(libjpeg)
Requires:       pkgconfig(libpng)
Requires:       pkgconfig(zlib)

%description    devel
Development files for %{name}.

%package        static
Summary:        Static libraries for %{name}
Requires:       %{name}-devel = %{version}-%{release}

%description static
%{summary}.

%package        fluid
Summary:        Fast Light User Interface Designer
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-devel = %{version}-%{release}

%description fluid
%{summary}, an interactive GUI designer for %{name}. 

%if %{with mingw}
%package -n mingw32-fltk
Summary:       %{summary}
 
%description -n mingw32-fltk
%{_description}
 
# Win64
%package -n mingw64-fltk
Summary:       MinGW compiled fltk for the Win64 target
 
%description -n mingw64-fltk
%{_description}
 
%package -n mingw32-fltk-static
Summary:       %{summary}
 
%description -n mingw32-fltk-static
%{_description}
 
# Win64
%package -n mingw64-fltk-static
Summary:       MinGW compiled fltk for the Win64 target
 
%description -n mingw64-fltk-static
%{_description}
 
%{?mingw_debug_package}
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake -DFLTK_CONFIG_PATH:PATH=%{_libdir}/cmake/fltk \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DOPTION_BUILD_HTML_DOCUMENTATION:BOOL=ON \
       -DOPTION_BUILD_PDF_DOCUMENTATION:BOOL=OFF \
       -DOPTION_BUILD_SHARED_LIBS:BOOL=ON

%cmake_build

make docs -C %{_vpath_builddir}

%if %{with mingw}
%mingw_cmake -DOPTION_BUILD_SHARED_LIBS=TRUE
%mingw_make_build
%endif


%install
%cmake_install

# Deal with license file of same name
mv src/xutf8/COPYING ./COPYING.xutf8

# we only apply this hack to multilib arch's
%ifarch x86_64 
%global arch %(uname -m 2>/dev/null || echo undefined)
mv $RPM_BUILD_ROOT%{_bindir}/fltk-config \
   $RPM_BUILD_ROOT%{_bindir}/fltk-config-%{arch}
install -p -m755 -D %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}/fltk-config
%endif

%if %{with mingw}
%mingw_make_install
%mingw_debug_install_post
%endif

%generate_compatibility_deps

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/fluid.desktop


%ldconfig_scriptlets


%files
%license COPYING COPYING.xutf8
%dir %{abidir}
%{_libdir}/libfltk.so.1.3*
%{_libdir}/libfltk_forms.so.1.3*
%{_libdir}/libfltk_gl.so.1.3*
%{_libdir}/libfltk_images.so.1.3*
%{abidir}/libfltk.dump
%{abidir}/libfltk_forms.dump
%{abidir}/libfltk_gl.dump
%{abidir}/libfltk_images.dump

%files devel
%doc %{_vpath_builddir}/documentation/html
%{_bindir}/fltk-config
%{?arch:%{_bindir}/fltk-config-%{arch}}
%{_includedir}/FL/
%{_libdir}/libfltk.so
%{_libdir}/libfltk_forms.so
%{_libdir}/libfltk_gl.so
%{_libdir}/libfltk_images.so
%{_libdir}/cmake/fltk/
%{_mandir}/man1/fltk-config.1*
%{_mandir}/man3/fltk.3*
%{_mandir}/man6/*.6*

%files static
%{_libdir}/libfltk.a
%{_libdir}/libfltk_forms.a
%{_libdir}/libfltk_gl.a
%{_libdir}/libfltk_images.a

%files fluid
%{_bindir}/fluid
%{_mandir}/man1/fluid.1*
%{_datadir}/applications/fluid.desktop
%{_datadir}/mime/packages/fluid.xml
%{_datadir}/icons/hicolor/*/*/*

%if %{with mingw}
%files -n mingw32-fltk
%license COPYING COPYING.xutf8
%{mingw32_bindir}/fltk-config
%{mingw32_bindir}/libfltk.dll
%{mingw32_libdir}/libfltk.dll.a
%{mingw32_bindir}/libfltk_forms.dll
%{mingw32_libdir}/libfltk_forms.dll.a
%{mingw32_bindir}/libfltk_images.dll
%{mingw32_libdir}/libfltk_images.dll.a
%{mingw32_bindir}/libfltk_gl.dll
%{mingw32_libdir}/libfltk_gl.dll.a
%{mingw32_includedir}/FL/
%{mingw32_datadir}/cmake/fltk/
%exclude %{mingw32_datadir}/man/*

%files -n mingw64-fltk
%license COPYING COPYING.xutf8
%{mingw64_bindir}/fltk-config
%{mingw64_bindir}/libfltk.dll
%{mingw64_libdir}/libfltk.dll.a
%{mingw64_bindir}/libfltk_forms.dll
%{mingw64_libdir}/libfltk_forms.dll.a
%{mingw64_bindir}/libfltk_images.dll
%{mingw64_libdir}/libfltk_images.dll.a
%{mingw64_bindir}/libfltk_gl.dll
%{mingw64_libdir}/libfltk_gl.dll.a
%{mingw64_includedir}/FL/
%{mingw64_datadir}/cmake/fltk/
%exclude %{mingw64_datadir}/man/*

%files -n mingw32-fltk-static
%{mingw32_libdir}/libfltk.a
%{mingw32_libdir}/libfltk_forms.a
%{mingw32_libdir}/libfltk_images.a
%{mingw32_libdir}/libfltk_gl.a

%files -n mingw64-fltk-static
%{mingw64_libdir}/libfltk.a
%{mingw64_libdir}/libfltk_forms.a
%{mingw64_libdir}/libfltk_images.a
%{mingw64_libdir}/libfltk_gl.a
%endif

%files doc
%doc README README.*.txt CREDITS ANNOUNCEMENT CHANGES CHANGES_1* 


%changelog
* Fri Oct 28 2022 happy_orange <songnannan@linux.alibaba.com> - 1.3.8-1
- Init package from upstream
